instrumenttools.FrenchHorn
==========================

.. abjad-lineage:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn

.. autoclass:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.FrenchHorn.FrenchHorn.FrenchHorn.__repr__
   :noindex:
